@@ -390,3 +390,87 @@ class TheBlockchainAPIResource:
         if 'error_message' in response:
             raise Exception(response['error_message'])
         return response['transaction_signature']
+
+    def get_candy_machine_config_public_key(
+        self,
+        candy_machine_id: str,
+        network: SolanaNetwork = SolanaNetwork.DEVNET
+    ):
+        payload = {
+            "network": network.value,
+            "candy_machine_id": candy_machine_id
+        }
+        response = self._request(
+            payload=payload,
+            endpoint="solana/nft/candy_machine/config",
+            request_method=self.__RequestMethod.POST
+        )
+        if 'error_message' in response:
+            raise Exception(response['error_message'])
+        return response['config_address']
+
+    def get_candy_machine_info(
+        self,
+        candy_machine_id: str,
+        network: SolanaNetwork = SolanaNetwork.DEVNET
+    ):
+        payload = {
+            "network": network.value,
+            "candy_machine_id": candy_machine_id
+        }
+        response = self._request(
+            payload=payload,
+            endpoint="solana/nft/candy_machine/info",
+            request_method=self.__RequestMethod.POST
+        )
+        if 'error_message' in response:
+            raise Exception(response['error_message'])
+        return response
+
+    def mint_from_candy_machine(
+        self,
+        candy_machine_id: str,
+        secret_recovery_phrase: str,
+        derivation_path: Optional[str] = None,
+        passphrase: str = str(),
+        network: SolanaNetwork = SolanaNetwork.DEVNET
+    ):
+        payload = {
+            "secret_recovery_phrase": secret_recovery_phrase,
+            "network": network.value,
+            "passphrase": passphrase,
+            "candy_machine_id": candy_machine_id
+        }
+        if derivation_path is not None:
+            payload['derivation_path'] = derivation_path
+        response = self._request(
+            payload=payload,
+            endpoint="solana/nft/candy_machine/mint",
+            request_method=self.__RequestMethod.POST
+        )
+        if 'error_message' in response:
+            raise Exception(response['error_message'])
+        return response['transaction_signature']
+
+    def create_candy_machine(
+        self,
+        secret_recovery_phrase: str,
+        derivation_path: Optional[str] = None,
+        passphrase: str = str(),
+        network: SolanaNetwork = SolanaNetwork.DEVNET
+    ):
+        payload = {
+            "secret_recovery_phrase": secret_recovery_phrase,
+            "network": network.value,
+            "passphrase": passphrase
+        }
+        if derivation_path is not None:
+            payload['derivation_path'] = derivation_path
+        response = self._request(
+            payload=payload,
+            endpoint="solana/nft/candy_machine",
+            request_method=self.__RequestMethod.POST
+        )
+        if 'error_message' in response:
+            raise Exception(response['error_message'])
+        return response['candy_machine_address']
